Breezy Developer Document Catalog — Breezy 3.0.2dev documentation

Developer Document Catalog (3.0.2dev)

# Breezy Developer Document Catalog

## Introduction

- Contributing to Breezy

## Working on Breezy

- Profiling
- Tracking Bugs in Breezy
- Breezy Developer Guide
- Breezy Testing Guide
- Reviewing proposed changes to Breezy
- Breezy Code Style Guide
- Documenting Changes

- Contributing to Breezy Documentation (wiki)

## Architecture overviews

- Configuring Breezy
- breezy.conf
- location.conf
- branch.conf
- Fetching data
- Developer guide to breezy transports
- Interacting with the user

## Releasing and Packaging

- Releasing Breezy
- Managing the Breezy PPA
- Breezy Windows EC2 Server

## Developing using breezy

- Breezy Architectural Overview
- Integrating with Breezy

- Writing plugins for Breezy

- breezy API reference

## Other documents

- Breezy Design Principles
- Specifications
- Implementation notes
- Miscellaneous notes

## Licence

Copyright 2005-2011 Canonical Ltd. Copyright 2018 Breezy Developers

Breezy is free software, and you may use, modify and redistribute both Breezy and this document under the terms of the GNU General Public License version 2 or later. See <http://www.gnu.org/licenses/>.